from setuptools import setup,find_packages

setup(
    name='wiseman_library',
    version='0.0.3',
    author='adem öcel',
    author_email='ademocel83@gmail.com',
    description='wiseman bundles the voice assistant infrastructure into a python library',
    packages=find_packages(),
    url='https://github.com/adem-ocel/wiseman-library',
    license='MIT license'
)
